# import pkg_resources

# TODO: Fix pkg_resources.DistributionNotFound error when running through Github Actions
# __version__ = pkg_resources.get_distribution("awssert").version

from awssert.hooks import *
